package i18n.boundary;

import jakarta.enterprise.context.RequestScoped;
import jakarta.ws.rs.GET;
import jakarta.ws.rs.POST;
import jakarta.ws.rs.Path;
import jakarta.ws.rs.core.Context;
import jakarta.ws.rs.core.HttpHeaders;
import jakarta.ws.rs.core.Response;
import java.util.Locale;

@Path("hello")
@RequestScoped
public class SomeResource {

    @Context
    HttpHeaders headers;

    @GET
    public Response hello() {
        final Locale locale = headers.getAcceptableLanguages().isEmpty() ? Locale.ENGLISH : headers.getAcceptableLanguages().get(0);

        return Response
                .ok("""
                    Accept-Language: %s
                             Parsed: %s
                    """.formatted(
                            headers.getHeaderString(HttpHeaders.ACCEPT_LANGUAGE),
                            locale.toLanguageTag()
                    ))
                .build();

    }

    @POST
    public Response compare(final String languageTag) {
        final Locale resolvedLocale = headers.getAcceptableLanguages().isEmpty() ? Locale.ENGLISH : headers.getAcceptableLanguages().get(0);
        final Locale parsedLocale = Locale.forLanguageTag(languageTag);

        return Response
                .ok("""
                      Parsed: %s - %s
                    Resolved: %s - %s
                    """.formatted(parsedLocale, parsedLocale.getDisplayName(), resolvedLocale, resolvedLocale.getDisplayName()))
                .build();
    }
}
